# DALL-E FOR FREE!

Use OpenAI's DALL-E for free
 
With dalle43 you can use  OpenAi's DALL-E for free

**UPDATE: dalle43 is now available for both Windows and Unix.**

# HOW TO USE

1. INSTALL DALLE43: `pip install -U dalle43`


2. GENERATE AN IMAGE

`import dalle43.dalle43 as DALL_E`

`DALL_E.show_img('the milky way')`



3. Enjoy! :heart:


![Screenshot from 2023-03-20 02-32-03](https://user-images.githubusercontent.com/114559605/226227544-66d2e956-8bd6-43d5-8397-41e720674b7a.png)
